.. _c_api:

API Documentation (C)
=====================

This documents the C API for REBOUNDx.
**The main reference point in the documentation is** :ref:`effects` **,which has descriptions for each effect and its parameters, citations, and links to examples.**

.. doxygenfile:: reboundx.h

